from monday.resources.base import BaseResource
from monday.query_joins import create_update_query, get_update_query


class UpdateResource(BaseResource):
    def __init__(self, token):
        super().__init__(token)

    def create_update(self, item_id, update_value):
        query = create_update_query(item_id, update_value)
        return self.client.execute(query)

    def fetch_updates(self, limit, page=None):
        query = get_update_query(limit, page)
        return self.client.execute(query)




from monday.utils import python_json_stringify


# ITEM RESOURCE QUERIES
def mutate_query_join(board, group, item, column_values):
    if column_values is None:
        column_values = {}

    query = '''mutation
    {
        create_item (
            board_id: %s,
            group_id: %s,
            item_name: "%s",
            column_values: %s
        ) {
            id
        }
    }''' % (board, group, item, python_json_stringify(column_values))

    return query


def get_query_join(board, column, value):
    query = '''query
        {
            items_by_column_values(
                board_id: %s,
                column_id: %s,
                column_value: "%s"
            ) {
                id
                name
                updates {
                    id
                    body
                }
                column_values {
                    id
                    text
                    value
                }
            }
        }''' % (board, column, value)

    return query


def update_query_join(board, item, column, value):
    query = '''mutation
        {
            change_column_value(
                board_id: %s,
                item_id: %s,
                column_id: %s,
                value: %s
            ) {
                id
                name
                column_values {
                    id
                    text
                    value
                }
            }
        }''' % (board, item, column, python_json_stringify(value))

    return query


# UPDATE RESOURCE QUERIES
def create_update_query(item_id, update_value):
    query = '''mutation
        {
            create_update(
                item_id: %s,
                body: "%s"
            ) {
                id
            }
        }''' % (item_id, update_value)

    return query


def get_update_query(limit, page):
    query = '''query
        {
            updates (
                limit: %s,
                page: %s
            ) {
                id,
                body
            }
        }''' % (limit, page if page else 1)

    return query


# TAG RESOURCE QUERIES
def get_tags_query(tags):
    if tags is None:
        tags = []

    query = '''query
        {
            tags (ids: %s) {
                name,
                color,
                id
            }
        }''' % tags

    return query



from monday.resources.base import BaseResource
from monday.query_joins import mutate_query_join, get_query_join, update_query_join


class ItemResource(BaseResource):
    def __init__(self, token):
        super().__init__(token)

    def create_item(self, board, group, item, column_values=None):
        query = mutate_query_join(board, group, item, column_values)
        return self.client.execute(query)

    def fetch_items(self, board, column, value):
        query = get_query_join(board, column, value)
        return self.client.execute(query)

    def change_item_value(self, board, item, column, value):
        query = update_query_join(board, item, column, value)
        return self.client.execute(query)




import json

from monday import __version__
from monday.exceptions import MondayError
from graphqlclient import GraphQLClient

_URLS = {
    'prod': 'https://api.monday.com/v2'
}

class BaseResource:
    def __init__(self, api_key):
        self._api_key = api_key
        self.client = GraphQLClient(_URLS['prod'])
        self.client.inject_token(api_key)

    def _query(self, query):
        result = self.client.execute(query)

        if result:
            return json.loads(result)

    def __str__(self):
        return self.__class__.__name__

    def __repr__(self):
        return self.__class__.__name__
